// Arduino IDE Sketch for Lian Li GPU Strimer Plus
// created by FeuerSturm
#include <CorsairLightingProtocol.h>
#include <FastLED.h>

#define LEDS_PER_DATA 27

// If you want to use other pins than 2,4,6,8 for the data lines instead, change them here:
#define STRIMER_DATA1 2
#define STRIMER_DATA2 4
#define STRIMER_DATA3 6
#define STRIMER_DATA4 8
// DO NOT EDIT BELOW THIS LINE UNLESS YOU KNOW WHAT YOU ARE DOING!

CRGB ledsChannel1[54];
CRGB ledsChannel2[54];

const char mySerialNumber[] PROGMEM = "2021A2B3C4D5";

CorsairLightingFirmwareStorageEEPROM firmwareStorage;
CorsairLightingFirmware firmware(CORSAIR_LIGHTING_NODE_PRO, &firmwareStorage);
FastLEDControllerStorageEEPROM storage;
FastLEDController ledController(&storage);
CorsairLightingProtocolController cLP(&ledController, &firmware);
CorsairLightingProtocolHID cHID(&cLP, mySerialNumber);

void setup()
{
	DeviceID deviceId = { 0xA2, 0xB3, 0xC4, 0xD5 };
	firmware.setDeviceID(deviceId);
	CLP::disableBuildInLEDs();
	FastLED.addLeds<WS2812B, STRIMER_DATA1, GRB>(ledsChannel1, LEDS_PER_DATA * 0, LEDS_PER_DATA);
	FastLED.addLeds<WS2812B, STRIMER_DATA2, GRB>(ledsChannel1, LEDS_PER_DATA * 1, LEDS_PER_DATA);
 
	FastLED.addLeds<WS2812B, STRIMER_DATA3, GRB>(ledsChannel2, LEDS_PER_DATA * 0, LEDS_PER_DATA);
	FastLED.addLeds<WS2812B, STRIMER_DATA4, GRB>(ledsChannel2, LEDS_PER_DATA * 1, LEDS_PER_DATA);
  
	ledController.addLEDs(0, ledsChannel1, 54);
	ledController.addLEDs(1, ledsChannel2, 54);
}

void loop()
{
	cHID.update();
  
	if (ledController.updateLEDs())
	{
		FastLED.show();
	}
}
